# zyxelprometheus
# Copyright (C) 2020 Andrew Wilkinson
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from .mock_sshclient import MockSSHClient

import paramiko.client

paramiko.client.SSHClient = MockSSHClient

from .test_arguments import TestArguments  # noqa
from .test_login import TestLogin  # noqa
from .test_prometheus import TestPrometheus  # noqa
from .test_scrape import TestScrape  # noqa
from .test_server import TestServer  # noqa
